#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>
#include <stdio.h>
#include "osc.h"

#define BUFLEN	16384

void
main(void)
{
	struct in_addr	in_addr;
	struct hostent	*hostent;
	char	buf[BUFLEN], *data;
	int	i, datalen;

	hostent = gethostbyname("infocalypse.al.cl.cam.ac.uk");
	if (!hostent) {
		perror("gethostbyname");
		exit(-1);
	}

	if (hostent->h_addrtype != AF_INET) {
		fprintf(stderr, "gethostbyname returned non-inet address\n");
		exit(-1);
	}

	if (hostent->h_length != sizeof(int)) {
		fprintf(stderr, "gethostbyname did not return an address\n");
		exit(-1);
	}

	in_addr.s_addr = *(int*)*hostent->h_addr_list;

	printf("%s\n", inet_ntoa(in_addr));

	i = osc_connect(in_addr, 4500, "GPIB0::7::INSTR");
	if (i) {
		perror("osc_connect");
		exit(-1);
	}

	i = osc_write(":dig");
	if (i == -1) {
		perror("osc_write");
		exit(-1);
	}

	i = osc_write(":waveform:data?");
	if (i == -1) {
		perror("osc_read");
		exit(-1);
	}

	i = osc_read(buf, BUFLEN);
	if (i <= 0) {
		perror("osc_read");
		exit(-1);
	}
	datalen = i;

	i = osc_waveform_parse(buf, datalen, &data);
	if (i == -1) {
		fprintf(stderr, "osc_waveform_parse failed\n");
		exit(-1);
	}

	printf("Read %d bytes from oscilloscope, data is %d bytes\n",
	    datalen, datalen - (data - buf));


}
